//
//  YHHKPlanDoctumentVC.swift
//  galaxy
//
//  Created by davidhuangA on 2024/3/31.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
/*
 赴港计划书
 */

class YHHKPlanDoctumentVC: YHBaseViewController {
    var tableView: UITableView!
    
    var viewModel: YHMyDocumentsDetailViewModel = {
        let vm = YHMyDocumentsDetailViewModel()
        return vm
    }()
    
    var supplement_id: Int = 0
    var status : Int = 0
    private var canEditFlag : Bool = false
    
    override func viewDidLoad() {
        super.viewDidLoad()
        gk_navTitle = "赴港计划书"
        gk_navBackgroundColor = .white
        gk_navBarAlpha = 1.0
        
        setView()
        getData()
    }
    
    override func viewWillAppear(_ animated: Bool) {
        super.viewWillAppear(animated)
        getData()
    }
    
    private var bottomView : UIView = {
        let view = UIView()
        view.backgroundColor = .white
        view.isHidden = true
        return view
    }()
    
    lazy var bottomButton : UIButton = {
        let button = UIButton(type: .custom)
        button.titleLabel?.font = UIFont.PFSC_B(ofSize: 15)
        button.contentHorizontalAlignment = .center
        button.setTitle("提交", for: .normal)
        button.setTitleColor( UIColor(hex:0xffffff), for: .normal)
        button.layer.cornerRadius = kCornerRadius6
        button.clipsToBounds = true
        button.addTarget(self, action: #selector(clickSubmitBtn), for: .touchUpInside)
        return button
    }()
}

extension YHHKPlanDoctumentVC {
    //点击提交按钮
    @objc func clickSubmitBtn() {
        submitOp()
    }
    
    //提交数据
    private func submitOp() {
        
        if viewModel.arrHKPlanData.count > 5 {
            
            
            if let orderID = UserDefaults.standard.value(forKey: "orderIdForPreview") {
                let params = ["order_id":orderID,
                              "supplement_id":supplement_id,
                              "career_achievement":viewModel.arrHKPlanData[0].content,
                              "professional_skills":viewModel.arrHKPlanData[1].content,
                              "academic_achievement":viewModel.arrHKPlanData[2].content,
                              "plan_detail":viewModel.arrHKPlanData[3].content,
                              "qualifications_and_awards":viewModel.arrHKPlanData[4].content,
                              "other":viewModel.arrHKPlanData[5].content,
                              "content_save":1]
                
                viewModel.submitHKPlanDocument(params) { success, error in
                    if success {
                        YHHUD.flash(message: "提交成功")
                    } else {
                        YHHUD.flash(message: error?.errorMsg ?? "提交失败")
                    }
                }
            } else {
                YHHUD.flash(message: "订单ID 为空")
            }
        } else {
            YHHUD.flash(message: "参数不合法")
        }
    }
    
    func getData() {
        viewModel.requestDocumentsDetail("\(supplement_id)", callBackBlock: {[weak self] success, error in
            guard let self = self else { return }
            
            for item in viewModel.arrHKPlanData {
                item.canEditFlag = self.canEditFlag
            }
            self.tableView.reloadData()
        })
    }
    
    func setView() {
        let tipsHoldView : UIView = UIView()
        tipsHoldView.backgroundColor = UIColor(hex: 0xE8F1FF, alpha: 1.0)
        tipsHoldView.frame = CGRect(x: 0, y: 0, width: KScreenWidth, height: 36.0)
        bottomView.addSubview(tipsHoldView)
        tipsHoldView.snp.makeConstraints { make in
            make.top.equalTo(0)
            make.left.right.equalTo(0)
            make.height.equalTo(36)
        }
        
        let iconImagV : UIImageView = UIImageView(image: UIImage(named: "my_doc_tips_icon"))
        iconImagV.contentMode = .scaleAspectFill
        tipsHoldView.addSubview(iconImagV)
        iconImagV.snp.makeConstraints { make in
            make.centerY.equalToSuperview()
            make.left.equalTo(kMargin)
            make.width.height.equalTo(kMargin)
        }
        
        let tipsLable : UILabel = UILabel(text: "请确认文书内容，修改完成后点击提交。")
        tipsLable.textColor = .brandMainColor
        tipsLable.font = UIFont.PFSC_M(ofSize: 12)
        tipsHoldView.addSubview(tipsLable)
        tipsLable.snp.makeConstraints { make in
            make.centerY.equalToSuperview()
            make.left.equalTo(iconImagV.snp.right).offset(4)
            make.height.equalTo(20)
            make.right.equalToSuperview().offset(-kMargin)
        }
        
        bottomView.addSubview(bottomButton)
        bottomButton.snp.makeConstraints { make in
            make.top.equalTo(tipsHoldView.snp.bottom)
            make.left.equalTo(kMargin)
            make.right.equalTo(-kMargin)
            make.height.equalTo(48)
        }
        
        
        view.addSubview(bottomView)
        bottomView.snp.makeConstraints { make in
            make.bottom.left.right.equalToSuperview()
            make.height.equalTo(120)
        }
        
        bottomView.layoutIfNeeded()
        bottomButton.addYinHeGradualLayer()
        
        
        
        tableView = {
            let tableView = UITableView(frame:.zero, style:.plain)
            tableView.contentInsetAdjustmentBehavior = .never
            tableView.backgroundColor = .clear
            tableView.separatorStyle = .none
            tableView.delegate = self
            tableView.dataSource = self
            tableView.register(cellWithClass: YHHKPlanCell.self)
            tableView.register(cellWithClass: YHHKPlanTipsCell.self)
            return tableView
        }()
        
        view.addSubview(tableView)
        
        if status > 4 {
            canEditFlag = false
            bottomView.isHidden = true
            
            tableView.snp.makeConstraints { make in
                make.top.equalTo(k_Height_NavigationtBarAndStatuBar)
                make.left.right.equalToSuperview()
                make.bottom.equalToSuperview()
            }
        } else {
            canEditFlag = true
            bottomView.isHidden = false
            tableView.snp.makeConstraints { make in
                make.top.equalTo(k_Height_NavigationtBarAndStatuBar)
                make.left.right.equalToSuperview()
                make.bottom.equalTo(bottomView.snp.top).offset(-kMargin)
            }
        }
    }
}

extension YHHKPlanDoctumentVC: UITableViewDelegate, UITableViewDataSource {
    
    func numberOfSections(in tableView: UITableView) -> Int {
        return 2
    }
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        if section == 0 {
            return 1
        }
        return viewModel.arrHKPlanData.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        if indexPath.section == 0 {
            let cell = tableView.dequeueReusableCell(withClass: YHHKPlanTipsCell.self)
            cell.selectionStyle = .none
            return cell
        }
        
        
        let cell = tableView.dequeueReusableCell(withClass: YHHKPlanCell.self)
        cell.selectionStyle = .none
        cell.dataMode = viewModel.arrHKPlanData[indexPath.row]
        return cell
    }
    
    func tableView(_ tableView: UITableView, heightForRowAt indexPath: IndexPath) -> CGFloat {
        return UITableView.automaticDimension
    }
}
